pub struct RelayContext { /* private fields */ }Expand description
Relay context.
Implementations
Sourceimpl RelayContext
impl RelayContext
Sourcepub fn new(
topology_context: &TopologyContext,
component_context: &ComponentContext,
component_registry: ComponentRegistry,
health_handle: Health,
dispatcher: PayloadsDispatcher,
spawner: ComponentSpawner,
) -> Self
pub fn new( topology_context: &TopologyContext, component_context: &ComponentContext, component_registry: ComponentRegistry, health_handle: Health, dispatcher: PayloadsDispatcher, spawner: ComponentSpawner, ) -> Self
Creates a new RelayContext.
Sourcepub fn take_shutdown_handle(&mut self) -> ShutdownHandle
pub fn take_shutdown_handle(&mut self) -> ShutdownHandle
Consumes the shutdown handle of this relay context.
Panics
Panics if the shutdown handle has already been taken.
Sourcepub fn take_health_handle(&mut self) -> Health
pub fn take_health_handle(&mut self) -> Health
Consumes the health handle of this relay context.
Panics
Panics if the health handle has already been taken.
Sourcepub fn topology_context(&self) -> &TopologyContext
pub fn topology_context(&self) -> &TopologyContext
Returns a reference to the topology context.
Sourcepub fn component_context(&self) -> &ComponentContext
pub fn component_context(&self) -> &ComponentContext
Returns a reference to the component context.
Sourcepub fn component_registry(&self) -> &ComponentRegistry
pub fn component_registry(&self) -> &ComponentRegistry
Returns a reference to the component registry.
Sourcepub fn dispatcher(&self) -> &PayloadsDispatcher
pub fn dispatcher(&self) -> &PayloadsDispatcher
Returns a reference to the payloads dispatcher.
Sourcepub fn spawner(&self) -> &ComponentSpawner
pub fn spawner(&self) -> &ComponentSpawner
Returns a spawner for supervised child tasks belonging to this component.
All child tasks spawned through this mechanism are tied to the lifecycle of the component itself, such that they’re automatically shutdown/stopped when the component is stopped during topology shutdown, etc.